#include <QtGui/QApplication>
#include <QtCore/QTranslator>

#include "mainwindow.h"

MainWindow *mw;

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);

    /* Install translation */
    QTranslator *qfTranslator = new QTranslator(qApp);

    if(qfTranslator->load(":/translations/qtify_" + QLocale::system().name())) {
        a.installTranslator(qfTranslator);
    } else {
        qDebug() << "No translation for " << QLocale::system().name() << " found, defaulting";
    }

    MainWindow w;
    mw = &w;
    w.show();
    return a.exec();
}
